@@ -31,7 +31,6 @@ from gi.repository import GdkPixbuf as GdkPixbuf
 import argparse
 import sys
 import traceback
-import imghdr
 
 # otherwise, on hardy the user is shown spurious "[application] closed
 # unexpectedly" messages but denied the ability to actually "report [the]
@@ -287,6 +286,14 @@ wa = display.get_monitor(0).get_workarea()
 max_h = wa.height - 192
 max_w = wa.width - 64
 
+def get_pointer(widget):
+    window = widget.get_window()
+    if window is None:
+        return None
+    display = window.get_display()
+    pointer = display.get_default_seat().get_pointer()
+    return window.get_device_position(pointer)
+
 class App:
     def __init__(self, *, round_right_and_bottom=False, files=[]):
         self.round_right_and_bottom = round_right_and_bottom
@@ -313,12 +320,15 @@ class App:
         self.drag.busy = is_busy
         i = self['image1']
         if i:
-            self.drag.idle_motion(*i.get_pointer())
+            pointer = get_pointer(i)
+            if pointer is not None:
+                self.drag.idle_motion(pointer.x, pointer.y)
 
     def run(self):
         drag = self.drag
         task = self.task
         prev_name = None
+        cropped_any_image = False
 
         for image_name in self.image_names():
             drag.save_prev_crop()
@@ -345,7 +355,7 @@ class App:
                 m.run()
                 m.destroy()
                 continue
-            image_type = imghdr.what(image_name)
+            image_type = image.format.lower() if image.format else "png"
             drag.image = thumbnail
             drag.rotation = 1
             rotation = image_rotation(image)
@@ -379,7 +389,10 @@ class App:
                     rotation=drag.rotation,
                     target=target,
                 ))
+                cropped_any_image = True
             if v == -1: break # user closed app
+        if not cropped_any_image:
+            raise SystemExit(1)
 
     def image_names(self):
         if self.files:
